@@ -11,11 +11,11 @@ public:
 	MethodCallBase(Smoke *smoke, const Smoke::Index meth, zval** sp);
 	MethodCallBase(Smoke *smoke, const Smoke::Index meth, const Smoke::Stack stack, zval** sp);
 	MethodCallBase(Smoke *smoke, const Smoke::Stack stack, zval** sp);
-	virtual ~MethodCallBase();
+	//	virtual ~MethodCallBase();
 
 	Smoke *smoke();
 	SmokeType type();
-	Smoke::StackItem &item();
+       	Smoke::StackItem &item();
 	const Smoke::Method &method();
 	virtual const int items() = 0;
 	virtual void callMethod() = 0;
@@ -29,7 +29,7 @@ protected:
 	int _cur;
 	Smoke::Index *_args;
 	bool _called;
-	zval **_sp;	
+	zval **_sp;
 };
 
 #endif /*METHODCALLBASE_H_*/
